@@ -152,6 +152,7 @@ FAMILY_UDI = "7"
 FAMILY_BRULTECH = "8"
 FAMILY_NCD = "9"
 FAMILY_NODESERVER = "10"
+FAMILY_ZMATTER_ZWAVE = "12"
 
 PROP_BATTERY_LEVEL = "BATLVL"
 PROP_BUSY = "BUSY"
@@ -720,7 +721,7 @@ INSTEON_RAMP_RATES = {
 
 # Thermostat Types/Categories. 4.8 Trane, 5.3 venstar, 5.10 Insteon Wireless,
 #  5.11 Insteon, 5.17 Insteon (EU), 5.18 Insteon (Aus/NZ)
-INSTEON_TYPE_THERMOSTAT = ["4.8", "5.3", "5.10", "5.11", "5.17", "5.18"]
+INSTEON_TYPE_THERMOSTAT = ["4.8", "5.3", "5.10", "5.11", "5.14", "5.17", "5.18"]
 ZWAVE_CAT_THERMOSTAT = ["140"]
 
 # Other special categories or types
@@ -732,14 +733,15 @@ INSTEON_SUBNODE_DIMMABLE = " 1"
 ZWAVE_CAT_DIMMABLE = ["109", "119", "186"]
 
 # Insteon Battery Devices - States are ignored when checking the status of a group.
-INSTEON_BATTERY_TYPE = ["0.16.", "0.17.", "0.18.", "16."]
-INSTEON_BATTERY_NODEDEFID = [
+INSTEON_STATELESS_TYPE = ["0.16.", "0.17.", "0.18.", "16."]  # Not Used
+INSTEON_STATELESS_NODEDEFID = [
     "BinaryAlarm",
     "BinaryAlarm_ADV",
     "BinaryControl",
     "BinaryControl_ADV",
     "RemoteLinc2",
     "RemoteLinc2_ADV",
+    "DimmerSwitchOnly",
 ]
 
 # Referenced from ISY-WSDK 4_fam.xml
