@@ -18,11 +18,13 @@ from ..constants import (
     FAMILY_BRULTECH,
     FAMILY_NODESERVER,
     FAMILY_RCS,
+    FAMILY_ZMATTER_ZWAVE,
     FAMILY_ZWAVE,
     INSTEON_RAMP_RATES,
     ISY_VALUE_UNKNOWN,
     NC_NODE_ERROR,
     NODE_CHANGED_ACTIONS,
+    PROP_BATTERY_LEVEL,
     PROP_COMMS_ERROR,
     PROP_RAMP_RATE,
     PROP_STATUS,
@@ -264,6 +266,12 @@ class Nodes:
         ):
             # Clear a previous comms error
             del node.aux_properties[PROP_COMMS_ERROR]
+        if cntrl == PROP_BATTERY_LEVEL and node.is_battery_node:
+            # Update the state if this is a battery node
+            node.update_state(
+                NodeProperty(PROP_STATUS, value, prec, uom, formatted, address)
+            )
+            _LOGGER.debug("ISY Updated Node: " + address)
         elif cntrl not in EVENT_PROPS_IGNORED:
             node.update_property(node_property)
         node.control_events.notify(node_property)
@@ -300,6 +308,9 @@ class Nodes:
                 # Get Node Information
                 address = value_from_xml(feature, TAG_ADDRESS)
                 nname = value_from_xml(feature, TAG_NAME)
+
+                _LOGGER.debug("Parsing %s: %s [%s]", ntype, nname, address)
+
                 nparent = value_from_xml(feature, TAG_PARENT)
                 pnode = value_from_xml(feature, TAG_PRIMARY_NODE)
                 family = value_from_xml(feature, TAG_FAMILY)
@@ -312,7 +323,7 @@ class Nodes:
                 zwave_props = None
                 node_server = None
                 if family is not None:
-                    if family == FAMILY_ZWAVE:
+                    if family in (FAMILY_ZWAVE, FAMILY_ZMATTER_ZWAVE):
                         protocol = PROTO_ZWAVE
                         zwave_props = ZWaveProperties(
                             feature.getElementsByTagName(TAG_DEVICE_TYPE)[0]
@@ -332,7 +343,7 @@ class Nodes:
                     if address in self.addresses:
                         self.get_by_id(address).update(xmldoc=feature)
                         continue
-                    state, aux_props = parse_xml_properties(feature)
+                    state, aux_props, state_set = parse_xml_properties(feature)
                     self.insert(
                         address,
                         nname,
@@ -351,6 +362,7 @@ class Nodes:
                             node_server=node_server,
                             protocol=protocol,
                             family_id=family,
+                            state_set=state_set,
                         ),
                         ntype,
                     )
